@@ -13,20 +13,19 @@
 # limitations under the License.
 
 from abc import abstractmethod
-from typing import Sequence, cast, Optional, List, Sequence, Union
+from typing import Sequence, cast, Optional, List, Union
 from uuid import uuid4
 from cirq.sim import (
     CliffordSimulator,
     CliffordSimulatorStepResult,
     DensityMatrixSimulator,
-    DensityMatrixTrialResult,
     Simulator,
-    SparseSimulatorStep,
     StateVectorTrialResult,
 )
 
-# import cirq
 from cirq import ops
+from cirq.value import RANDOM_STATE_OR_SEED_LIKE
+from cirq.devices import NOISE_MODEL_LIKE
 from cirq.circuits import Circuit as CirqCircuit
 
 from pytket.circuit import Circuit, OpType, Qubit  # type: ignore
@@ -37,7 +36,7 @@ from pytket.passes import (  # type: ignore
     SequencePass,
     RebaseCustom,
     SquashCustom,
-    SynthesiseIBM,
+    SynthesiseTket,
     DecomposeBoxes,
     FlattenRegisters,
     RemoveRedundancies,
@@ -54,7 +53,7 @@ from pytket.backends.backendresult import BackendResult
 from pytket.backends.backendinfo import BackendInfo
 from pytket.backends.resulthandle import _ResultIdTuple
 from pytket.utils.results import KwargTypes
-from pytket.extensions.cirq import tk_to_cirq
+from pytket.extensions.cirq.cirq_convert import tk_to_cirq  # type: ignore
 from pytket.utils.outcomearray import OutcomeArray
 from .cirq_utils import _get_default_uids
 
@@ -103,17 +102,6 @@ class _CirqBaseBackend(Backend):
         self._check_handle_type(handle)
         return CircuitStatus(StatusEnum.COMPLETED)
 
-    @abstractmethod
-    def set_simulator(
-        self, **kwargs: KwargTypes
-    ) -> Union[Simulator, DensityMatrixSimulator, CliffordSimulator]:
-        """
-        Returns Cirq simulator object, seeded if given as kwarg.
-        :return: Cirq Simulator
-        :rtype: Union[Simulator, DensityMatrixSimulator, CliffordSimulator]
-        """
-        ...
-
 
 class _CirqSampleBackend(_CirqBaseBackend):
     """Common base class for all Cirq simulator sampling backends"""
@@ -122,17 +110,17 @@ class _CirqSampleBackend(_CirqBaseBackend):
         super().__init__()
         self._supports_shots: bool = True
         self._supports_counts: bool = True
+        self._simulator: Union[
+            Simulator, DensityMatrixSimulator, CliffordSimulator
+        ] = Simulator()
 
-    def run_circuit(self, circuit: Circuit, **kwargs: KwargTypes) -> BackendResult:
+    def _run_circuit(self, circuit: Circuit, n_shots: int) -> BackendResult:
         cirq_circ = tk_to_cirq(circuit)
         bit_to_qubit_map = {b: q for q, b in circuit.qubit_to_bit_map.items()}
         if not cirq_circ.has_measurements():  # type: ignore
-            n_shots = cast(int, kwargs.get("n_shots"))
             return self.empty_result(circuit, n_shots=n_shots)
         else:
-            run = self._simulator.run(
-                cirq_circ, repetitions=cast(int, kwargs.get("n_shots"))
-            )
+            run = self._simulator.run(cirq_circ, repetitions=n_shots)
             run_dict = run.data.to_dict()
             c_bits = [
                 bit
@@ -151,28 +139,17 @@ class _CirqSampleBackend(_CirqBaseBackend):
     def process_circuits(
         self,
         circuits: Sequence[Circuit],
-        n_shots: Optional[Union[int, Sequence[int]]] = None,
+        n_shots: Union[None, int, Sequence[Optional[int]]] = None,
         valid_check: bool = True,
         **kwargs: KwargTypes,
     ) -> List[ResultHandle]:
         circuits = list(circuits)
-        n_shots_list: List[int] = []
-        if hasattr(n_shots, "__iter__"):
-            for n in cast(Sequence[Optional[int]], n_shots):
-                if n is None or n < 1:
-                    raise ValueError(
-                        "n_shots values are required for all circuits for this backend"
-                    )
-                n_shots_list.append(n)
-            if len(n_shots_list) != len(circuits):
-                raise ValueError("The length of n_shots and circuits must match")
-        else:
-            if n_shots is None:
-                raise ValueError("Parameter n_shots is required for this backend")
-            # convert n_shots to a list
-            n_shots_list = [cast(int, n_shots)] * len(circuits)
+        n_shots_list = Backend._get_n_shots_as_list(
+            n_shots,
+            len(circuits),
+            optional=False,
+        )
 
-        self._simulator = self.set_simulator(seed=kwargs.get("seed"))
         if valid_check:
             self._check_all_circuits(circuits)
 
@@ -180,7 +157,7 @@ class _CirqSampleBackend(_CirqBaseBackend):
         for i, (circuit, n_shots) in enumerate(zip(circuits, n_shots_list)):
             handle = ResultHandle(str(uuid4()), i)
             handle_list.append(handle)
-            backres = self.run_circuit(circuit, n_shots=n_shots)
+            backres = self._run_circuit(circuit, n_shots=n_shots)
             self._cache[handle] = {"result": backres}
 
         return handle_list
@@ -189,31 +166,36 @@ class _CirqSampleBackend(_CirqBaseBackend):
 class CirqStateSampleBackend(_CirqSampleBackend):
     """Backend for Cirq statevector simulator sampling."""
 
-    def set_simulator(self, **kwargs: KwargTypes) -> Simulator:
-        return Simulator(seed=kwargs.get("seed"))
+    def __init__(self, seed: RANDOM_STATE_OR_SEED_LIKE = None) -> None:
+        super().__init__()
+        self._simulator = Simulator(seed=seed)
 
 
 class CirqDensityMatrixSampleBackend(_CirqSampleBackend):
     """Backend for Cirq density matrix simulator sampling."""
 
-    def set_simulator(self, **kwargs: KwargTypes) -> DensityMatrixSimulator:
-        return DensityMatrixSimulator(seed=kwargs.get("seed"))
+    def __init__(
+        self,
+        seed: RANDOM_STATE_OR_SEED_LIKE = None,
+        noise_model: NOISE_MODEL_LIKE = None,
+    ) -> None:
+        super().__init__()
+        self._supports_density_matrix = True
+        self._simulator = DensityMatrixSimulator(seed=seed, noise=noise_model)
 
 
 class CirqCliffordSampleBackend(_CirqSampleBackend):
     """Backend for Cirq Clifford simulator sampling."""
 
-    def __init__(self) -> None:
+    def __init__(self, seed: RANDOM_STATE_OR_SEED_LIKE = None) -> None:
         super().__init__()
+        self._simulator = CliffordSimulator(seed=seed)
         self._pass_0 = clifford_pass_0
         self._pass_1 = clifford_pass_1
         self._pass_2 = clifford_pass_2
         self._gate_set_predicate = _clifford_gate_set_predicate
         self._clifford_only = True
 
-    def set_simulator(self, **kwargs: KwargTypes) -> CliffordSimulator:
-        return CliffordSimulator(seed=kwargs.get("seed"))
-
 
 class _CirqSimBackend(_CirqBaseBackend):
     """Common base class for all Cirq simulator matrix/state returning backends."""
@@ -233,7 +215,7 @@ class _CirqSimBackend(_CirqBaseBackend):
         """
         ...
 
-    def run_circuit(self, circuit: Circuit, **kwargs: KwargTypes) -> BackendResult:
+    def _run_circuit(self, circuit: Circuit) -> BackendResult:
         cirq_circ = tk_to_cirq(circuit, copy_all_qubits=True)
         _, q_bits = _get_default_uids(cirq_circ, circuit)
         return self.package_result(cirq_circ, q_bits)
@@ -246,23 +228,17 @@ class _CirqSimBackend(_CirqBaseBackend):
         **kwargs: KwargTypes,
     ) -> List[ResultHandle]:
 
-        if hasattr(n_shots, "__iter__"):
-            n_shots_list = cast(List[Optional[int]], n_shots)
-            if len(n_shots_list) != len(circuits):
-                raise ValueError("The length of n_shots and circuits must match")
-        else:
-            # convert n_shots to a list
-            n_shots_list = [cast(int, n_shots)] * len(circuits)
+        if n_shots is not None:
+            raise ValueError("`n_shots` argument is invalid for _CirqSimBackend")
 
-        self._simulator = self.set_simulator(seed=kwargs.get("seed"))
         if valid_check:
             self._check_all_circuits(circuits)
 
         handle_list = []
-        for i, (circuit, n_shots) in enumerate(zip(circuits, n_shots_list)):
+        for i, circuit in enumerate(circuits):
             handle = ResultHandle(str(uuid4()), i)
             handle_list.append(handle)
-            backres = self.run_circuit(circuit, n_shots=n_shots)
+            backres = self._run_circuit(circuit)
             self._cache[handle] = {"result": backres}
 
         return handle_list
@@ -282,9 +258,7 @@ class _CirqSimBackend(_CirqBaseBackend):
         """
         ...
 
-    def run_circuit_moments(
-        self, circuit: Circuit, **kwargs: KwargTypes
-    ) -> List[BackendResult]:
+    def _run_circuit_moments(self, circuit: Circuit) -> List[BackendResult]:
         cirq_circ = tk_to_cirq(circuit, copy_all_qubits=True)
         _, q_bits = _get_default_uids(cirq_circ, circuit)
         return self.package_results(cirq_circ, q_bits)
@@ -317,10 +291,6 @@ class _CirqSimBackend(_CirqBaseBackend):
         get_<data> method. The get_<data> method will return List[BackendResult]
         corresponding to each moment.
 
-        Use keyword arguments to specify parameters to be used in submitting circuits:
-
-        * `seed`: RNG seed for simulators
-
         :param circuits: Circuits to process on the backend.
         :type circuits: Iterable[Circuit]
         :param valid_check: Explicitly check that all circuits satisfy all required
@@ -331,7 +301,6 @@ class _CirqSimBackend(_CirqBaseBackend):
         :rtype: List[ResultHandle]
         """
 
-        self._simulator = self.set_simulator(seed=kwargs.get("seed"))
         if valid_check:
             self._check_all_circuits(circuits)
 
@@ -339,7 +308,7 @@ class _CirqSimBackend(_CirqBaseBackend):
         for i, circuit in enumerate(circuits):
             handle = ResultHandle(str(uuid4()), i)
             handle_list.append(handle)
-            backres = self.run_circuit_moments(circuit)
+            backres = self._run_circuit_moments(circuit)
             self._cache[handle] = {"result": backres}  # type: ignore
 
         return handle_list
@@ -348,25 +317,21 @@ class _CirqSimBackend(_CirqBaseBackend):
 class CirqStateSimBackend(_CirqSimBackend):
     """Backend for Cirq statevector simulator state return."""
 
-    def __init__(self) -> None:
+    def __init__(self, seed: RANDOM_STATE_OR_SEED_LIKE = None) -> None:
         super().__init__()
+        self._simulator = Simulator(seed=seed)
         self._supports_state = True
 
-    def set_simulator(self, **kwargs: KwargTypes) -> Simulator:
-        return Simulator(seed=kwargs.get("seed"))
-
     def package_result(
         self, circuit: CirqCircuit, q_bits: Sequence[Qubit]
     ) -> BackendResult:
-        run = cast(
-            StateVectorTrialResult,
-            self._simulator.simulate(
-                circuit,
-                qubit_order=ops.QubitOrder.as_qubit_order(
-                    ops.QubitOrder.DEFAULT
-                ).order_for(circuit.all_qubits()),
+        run = self._simulator.simulate(
+            circuit,
+            qubit_order=ops.QubitOrder.as_qubit_order(ops.QubitOrder.DEFAULT).order_for(
+                circuit.all_qubits()
             ),
         )
+
         return BackendResult(state=run.final_state_vector, q_bits=q_bits)
 
     def package_results(
@@ -380,7 +345,7 @@ class CirqStateSimBackend(_CirqSimBackend):
         )
         all_backres = [
             BackendResult(
-                state=cast(SparseSimulatorStep, run).state_vector(copy=True),
+                state=run.state_vector(copy=True),
                 q_bits=q_bits,
             )
             for run in moments
@@ -391,17 +356,19 @@ class CirqStateSimBackend(_CirqSimBackend):
 class CirqDensityMatrixSimBackend(_CirqSimBackend):
     """Backend for Cirq density matrix simulator density_matrix return."""
 
-    def __init__(self) -> None:
+    def __init__(
+        self,
+        seed: RANDOM_STATE_OR_SEED_LIKE = None,
+        noise_model: NOISE_MODEL_LIKE = None,
+    ) -> None:
         super().__init__()
         self._supports_density_matrix = True
-
-    def set_simulator(self, **kwargs: KwargTypes) -> DensityMatrixSimulator:
-        return DensityMatrixSimulator(seed=kwargs.get("seed"))
+        self._simulator = DensityMatrixSimulator(seed=seed, noise=noise_model)
 
     def package_result(
         self, circuit: CirqCircuit, q_bits: Sequence[Qubit]
     ) -> BackendResult:
-        run = cast(DensityMatrixTrialResult, self._simulator.simulate(circuit))
+        run = self._simulator.simulate(circuit)
         return BackendResult(density_matrix=run.final_density_matrix, q_bits=q_bits)
 
     def package_results(
@@ -422,16 +389,14 @@ class CirqDensityMatrixSimBackend(_CirqSimBackend):
 class CirqCliffordSimBackend(_CirqSimBackend):
     """Backend for Cirq Clifford simulator state return."""
 
-    def __init__(self) -> None:
+    def __init__(self, seed: RANDOM_STATE_OR_SEED_LIKE = None) -> None:
         super().__init__()
         self._pass_0 = clifford_pass_0
         self._pass_1 = clifford_pass_1
         self._pass_2 = clifford_pass_2
         self._gate_set_predicate = _clifford_gate_set_predicate
         self._supports_state = True
-
-    def set_simulator(self, **kwargs: KwargTypes) -> CliffordSimulator:
-        return CliffordSimulator(seed=kwargs.get("seed"))
+        self._simulator = CliffordSimulator(seed=seed)
 
     def package_result(
         self, circuit: CirqCircuit, q_bits: Sequence[Qubit]
@@ -557,7 +522,7 @@ regular_pass_1 = SequencePass(
     [
         FlattenRegisters(),
         DecomposeBoxes(),
-        SynthesiseIBM(),
+        SynthesiseTket(),
         RebaseCirq(),
         RemoveRedundancies(),
         _cirq_squash,
@@ -581,7 +546,7 @@ clifford_pass_1 = SequencePass(
     [
         FlattenRegisters(),
         DecomposeBoxes(),
-        SynthesiseIBM(),
+        SynthesiseTket(),
         RemoveRedundancies(),
         _partial_clifford_rebase,
     ]
